Index: trunk/MagicSoft/Mars/mcalib/MCalibrationCam.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationCam.cc	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationCam.cc	(revision 3645)
@@ -27,15 +27,28 @@
 // MCalibrationCam                                               
 //                                                               
-// Base class for camera Calibration results:
-//                                                               
+// Base class for Camera Calibration results. 
+//
+// Contains TClonesArrays for the following objects:
+// - fPixels:         Array of classes derived from MCalibrationPix, one entry 
+//                    per pixel. Has to be created
+// - fAverageAreas:   Array of classes derived from MCalibrationPix, one entry
+//                    per pixel AREA. Has to be created
+// - fAverageSectors: Array of classes derived from MCalibrationPix, one entry
+//                    per camera SECTOR. Has to be created
+//
+// - fAverageBadAreas: Array of classes derived from MBadPixelsPix, one entry
+//                     per pixel AREA. Is created automatically. 
+// - fAverageBadSectors: Array of classes derived from MBadPixelsPix, one entry
+//                    per camera SECTOR. Is created automatically.
+//
+// All TClonesArrays have to enlarged by the corresponding calls to (e.g. in MGeomApply): 
+// - InitSize()
+// - InitAverageAreas()
+// - InitAverageSectors() 
+//
 /////////////////////////////////////////////////////////////////////////////
 #include "MCalibrationCam.h"
 
-#include <TH2.h>
-#include <TCanvas.h>
 #include <TClonesArray.h>
-
-#include "MLog.h"
-#include "MLogManip.h"
 
 #include "MGeomCam.h"
@@ -55,8 +68,16 @@
 // Default constructor. 
 //
-// Creates a TClonesArray of MCalibrationPix containers, initialized to 1 entry
-// Later, a call to MCalibrationCam::InitSize(Int_t size) has to be performed
-//
-// Creates an MCalibrationBlindPix container 
+// Set the following pointer to NULL:
+// - fPixels
+// - fAverageAreas
+// - fAverageSectors
+//
+// Creates a TClonesArray of MBadPixelsPix containers for the TClonesArray's: 
+// - fAverageBadAreas
+// - fAverageBadSectors
+// all initialized to 1 entry
+//
+// Later, a call to InitAverageAreas() and InitAverageSectors() has to be performed in order 
+// to get the dimension correctly.
 //
 MCalibrationCam::MCalibrationCam(const char *name, const char *title)
@@ -73,8 +94,12 @@
 // --------------------------------------------------------------------------
 //
-// Delete the TClonesArray of MCalibrationPix containers
-// Delete the MCalibrationPINDiode and the MCalibrationBlindPix
-//
-// Delete the histograms if they exist
+// Deletes the following TClonesArray's of MCalibrationPix containers (if exist):
+// - fPixels
+// - fAverageAreas
+// - fAverageSectors
+//  
+// Deletes the following TClonesArray's of MBadPixelsPix containers (if exist):
+// - fAverageBadAreas
+// - fAverageBadSectors
 //
 MCalibrationCam::~MCalibrationCam()
@@ -98,140 +123,18 @@
 }
 
-// -------------------------------------------------------------------
-//
-//
-void MCalibrationCam::InitSize(const UInt_t i)
-{
-  fPixels->ExpandCreate(i);
-}
-
-void MCalibrationCam::InitAverageAreas(const UInt_t i)
-{
-  fAverageAreas->ExpandCreate(i);
-  fAverageBadAreas->ExpandCreate(i);
-}
-
-void MCalibrationCam::InitAverageSectors(const UInt_t i)
-{
-  fAverageSectors->ExpandCreate(i);
-  fAverageBadSectors->ExpandCreate(i);
-}
-
-// --------------------------------------------------------------------------
-//
-// This function returns the current size of the TClonesArray 
-// independently if the MCalibrationPix is filled with values or not.
-//
-// It is the size of the array fPixels.
-//
-Int_t MCalibrationCam::GetSize() const
-{
-  return fPixels->GetEntriesFast();
-}
-
-Int_t MCalibrationCam::GetAverageAreas() const
-{
-  return fAverageAreas->GetEntriesFast();
-}
-
-Int_t MCalibrationCam::GetAverageSectors() const
-{
-  return fAverageSectors->GetEntriesFast();
-}
-
-
-// --------------------------------------------------------------------------
-//
-// Get i-th pixel (pixel number)
-//
-MCalibrationPix &MCalibrationCam::operator[](UInt_t i)
-{
-  return *static_cast<MCalibrationPix*>(fPixels->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th pixel (pixel number)
-//
-const MCalibrationPix &MCalibrationCam::operator[](UInt_t i) const
-{
-  return *static_cast<MCalibrationPix*>(fPixels->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (area number)
-//
-MCalibrationPix &MCalibrationCam::GetAverageArea(UInt_t i)
-{
-  return *static_cast<MCalibrationPix*>(fAverageAreas->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (area number)
-//
-const MCalibrationPix &MCalibrationCam::GetAverageArea(UInt_t i) const 
-{
-  return *static_cast<MCalibrationPix*>(fAverageAreas->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (sector number)
-//
-MCalibrationPix &MCalibrationCam::GetAverageSector(UInt_t i)
-{
-  return *static_cast<MCalibrationPix*>(fAverageSectors->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (sector number)
-//
-const MCalibrationPix &MCalibrationCam::GetAverageSector(UInt_t i) const 
-{
-  return *static_cast<MCalibrationPix*>(fAverageSectors->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (area number)
-//
-MBadPixelsPix &MCalibrationCam::GetAverageBadArea(UInt_t i)
-{
-  return *static_cast<MBadPixelsPix*>(fAverageBadAreas->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (area number)
-//
-const MBadPixelsPix &MCalibrationCam::GetAverageBadArea(UInt_t i) const 
-{
-  return *static_cast<MBadPixelsPix*>(fAverageBadAreas->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (sector number)
-//
-MBadPixelsPix &MCalibrationCam::GetAverageBadSector(UInt_t i)
-{
-  return *static_cast<MBadPixelsPix*>(fAverageBadSectors->UncheckedAt(i));
-}
-
-// --------------------------------------------------------------------------
-//
-// Get i-th average pixel (sector number)
-//
-const MBadPixelsPix &MCalibrationCam::GetAverageBadSector(UInt_t i) const 
-{
-  return *static_cast<MBadPixelsPix*>(fAverageBadSectors->UncheckedAt(i));
-}
-
-
 // --------------------------------------
 //
+// Calls the ForEach macro for the TClonesArray fPixels with the argument Clear()
+// 
+// Loops over the fAverageAreas, calling the function Clear() for 
+// every entry in:
+// - fAverageAreas
+// - fAverageBadAreas
+// 
+// Loops over the fAverageSectors, calling the function Clear() for 
+// every entry in:
+// - fAverageSectors
+// - fAverageBadSectors
+// 
 void MCalibrationCam::Clear(Option_t *o)
 {
@@ -260,4 +163,160 @@
 }
 
+// -------------------------------------------------------------------
+//
+// Calls TClonesArray::ExpandCreate() for fPixels
+//
+void MCalibrationCam::InitSize(const UInt_t i)
+{
+  fPixels->ExpandCreate(i);
+}
+
+// -------------------------------------------------------------------
+//
+// Calls TClonesArray::ExpandCreate() for:
+// - fAverageAreas
+// - fAverageBadAreas
+//
+void MCalibrationCam::InitAverageAreas(const UInt_t i)
+{
+  fAverageAreas->ExpandCreate(i);
+  fAverageBadAreas->ExpandCreate(i);
+}
+
+// -------------------------------------------------------------------
+//
+// Calls TClonesArray::ExpandCreate() for:
+// - fAverageSectors
+// - fAverageBadSectors
+//
+void MCalibrationCam::InitAverageSectors(const UInt_t i)
+{
+  fAverageSectors->ExpandCreate(i);
+  fAverageBadSectors->ExpandCreate(i);
+}
+
+// --------------------------------------------------------------------------
+//
+// Returns the current size of the TClonesArray fPixels 
+// independently if the MCalibrationPix is filled with values or not.
+//
+Int_t MCalibrationCam::GetSize() const
+{
+  return fPixels->GetEntriesFast();
+}
+
+// --------------------------------------------------------------------------
+//
+// Returns the current size of the TClonesArray fAverageAreas
+// independently if the MCalibrationPix is filled with values or not.
+//
+Int_t MCalibrationCam::GetAverageAreas() const
+{
+  return fAverageAreas->GetEntriesFast();
+}
+
+// --------------------------------------------------------------------------
+//
+// Returns the current size of the TClonesArray fAverageSectors
+// independently if the MCalibrationPix is filled with values or not.
+//
+Int_t MCalibrationCam::GetAverageSectors() const
+{
+  return fAverageSectors->GetEntriesFast();
+}
+
+
+// --------------------------------------------------------------------------
+//
+// Get i-th pixel (pixel number)
+//
+MCalibrationPix &MCalibrationCam::operator[](UInt_t i)
+{
+  return *static_cast<MCalibrationPix*>(fPixels->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th pixel (pixel number)
+//
+const MCalibrationPix &MCalibrationCam::operator[](UInt_t i) const
+{
+  return *static_cast<MCalibrationPix*>(fPixels->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (area number)
+//
+MCalibrationPix &MCalibrationCam::GetAverageArea(UInt_t i)
+{
+  return *static_cast<MCalibrationPix*>(fAverageAreas->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (area number)
+//
+const MCalibrationPix &MCalibrationCam::GetAverageArea(UInt_t i) const 
+{
+  return *static_cast<MCalibrationPix*>(fAverageAreas->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (sector number)
+//
+MCalibrationPix &MCalibrationCam::GetAverageSector(UInt_t i)
+{
+  return *static_cast<MCalibrationPix*>(fAverageSectors->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (sector number)
+//
+const MCalibrationPix &MCalibrationCam::GetAverageSector(UInt_t i) const 
+{
+  return *static_cast<MCalibrationPix*>(fAverageSectors->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (area number)
+//
+MBadPixelsPix &MCalibrationCam::GetAverageBadArea(UInt_t i)
+{
+  return *static_cast<MBadPixelsPix*>(fAverageBadAreas->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (area number)
+//
+const MBadPixelsPix &MCalibrationCam::GetAverageBadArea(UInt_t i) const 
+{
+  return *static_cast<MBadPixelsPix*>(fAverageBadAreas->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (sector number)
+//
+MBadPixelsPix &MCalibrationCam::GetAverageBadSector(UInt_t i)
+{
+  return *static_cast<MBadPixelsPix*>(fAverageBadSectors->UncheckedAt(i));
+}
+
+// --------------------------------------------------------------------------
+//
+// Get i-th average pixel (sector number)
+//
+const MBadPixelsPix &MCalibrationCam::GetAverageBadSector(UInt_t i) const 
+{
+  return *static_cast<MBadPixelsPix*>(fAverageBadSectors->UncheckedAt(i));
+}
+
+
+
 // --------------------------------------------------------------------------
 //
@@ -273,5 +332,5 @@
 // --------------------------------------------------------------------------
 //
-// What MHCamera needs in order to draw an individual pixel in the camera
+// Calls MCalibrationPix::DrawClone()
 //
 void MCalibrationCam::DrawPixelContent(Int_t idx) const
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationCam.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationCam.h	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationCam.h	(revision 3645)
@@ -64,5 +64,5 @@
   virtual Bool_t GetPixelContent(Double_t &val, Int_t idx, const MGeomCam &cam, Int_t type=0) const;
 
-  ClassDef(MCalibrationCam, 1)	// Base class Container for camera calibration
+  ClassDef(MCalibrationCam, 1)	// Base class Container for Calibration Results Camera
 };
 
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.cc	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.cc	(revision 3645)
@@ -102,7 +102,6 @@
 const Float_t MCalibrationChargePix::gkFFactorErr               = 0.02;
 
-const Float_t MCalibrationChargePix::gkConversionHiLo           = 10.;
-const Float_t MCalibrationChargePix::gkConversionHiLoErr        = 2.5;
-
+const Float_t MCalibrationChargePix::fgConversionHiLo           = 10.;
+const Float_t MCalibrationChargePix::fgConversionHiLoErr        = 2.5;
 const Float_t MCalibrationChargePix::fgPheFFactorMethodLimit    = 5.;
 // --------------------------------------------------------------------------
@@ -538,6 +537,6 @@
 {
 
-  fElectronicPedRms       = gkElectronicPedRms    * TMath::Sqrt(logainsamples);
-  fElectronicPedRmsVar    = gkElectronicPedRmsErr * gkElectronicPedRmsErr * logainsamples;
+  const Float_t elecPedRms     = gkElectronicPedRms    * TMath::Sqrt(logainsamples);
+  const Float_t elecPedRmsVar  = gkElectronicPedRmsErr * gkElectronicPedRmsErr * logainsamples;
   
   Float_t pedRmsSquare      = fPedRms * fPedRms;
@@ -550,6 +549,6 @@
   // We extract the pure NSB contribution:
   //
-  const Float_t elecRmsSquare    =    fElectronicPedRms    * fElectronicPedRms;
-  const Float_t elecRmsSquareVar = 4.*fElectronicPedRmsVar * elecRmsSquare;
+  const Float_t elecRmsSquare    =    elecPedRms    * elecPedRms;
+  const Float_t elecRmsSquareVar = 4.*elecPedRmsVar * elecRmsSquare;
   
   Float_t nsbSquare             =  pedRmsSquare    - elecRmsSquare;
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.h	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.h	(revision 3645)
@@ -6,23 +6,17 @@
 #endif
 
-class MBadPixelsPix;
 class MCalibrationChargePix : public MCalibrationPix
 {
 private:
 
-  static const Float_t gkConversionHiLo;         // The default conversion factor HI gain - Lo Gain
-  static const Float_t gkConversionHiLoErr;      // The error of the default conversion factor
+  static const Float_t gkElectronicPedRms;       //! Electronic component of ped. RMS   (now set to: 1.5)
+  static const Float_t gkElectronicPedRmsErr;    //! Error Electronic component of ped. RMS (now set to: 0.3)
+  static const Float_t gkFFactor;                //! Laboratory F-factor PMTs           (now set to: 1.15)
+  static const Float_t gkFFactorErr;             //! Laboratory F-factor Error PMTs     (now set to: 0.02)
+
+  static const Float_t fgConversionHiLo;         //! Default for fConversionHiLo        (now set to: 10.)
+  static const Float_t fgConversionHiLoErr;      //! Default for fConversionHiLoVar     (now set to: 2.5)
+  static const Float_t fgPheFFactorMethodLimit;  //! Default for fPheFFactorMethodLimit (now set to: 5.)
   
-  static const Float_t gkElectronicPedRms;       // The pure electronic component of the RMS
-  static const Float_t gkElectronicPedRmsErr;    // The error of the pure electronic component of the RMS
-  static const Float_t gkFFactor;                // The laboratory F-factor of the PMTs
-  static const Float_t gkFFactorErr;             // The laboratory F-factor Error of the PMTs
-
-
-  static const Float_t fgPheFFactorMethodLimit;  // The default minimum number of Photo-electrons for a pixel to be accepted.
-  
-  Float_t fElectronicPedRms;        // The pure electronic component of the RMS
-  Float_t fElectronicPedRmsVar;     // The error of the pure electronic component of the RMS
-
   Float_t fPheFFactorMethodLimit;   // The minimum number of Photo-electrons for a pixel to be accepted.
   
@@ -89,6 +83,6 @@
   void SetPedestal(const Float_t ped, const Float_t pedrms, const Float_t pederr);
 
-  void SetConversionHiLo(     const Float_t c = gkConversionHiLo)       { fConversionHiLo      = c;    }
-  void SetConversionHiLoErr(  const Float_t e = gkConversionHiLoErr)    { fConversionHiLoVar   = e*e;    }
+  void SetConversionHiLo(     const Float_t c = fgConversionHiLo)       { fConversionHiLo      = c;    }
+  void SetConversionHiLoErr(  const Float_t e = fgConversionHiLoErr)    { fConversionHiLoVar   = e*e;    }
 
   void SetPheFFactorMethodLimit ( const Float_t f=fgPheFFactorMethodLimit  ) { fPheFFactorMethodLimit  = f;   }
@@ -179,5 +173,5 @@
   Bool_t CalcFFactorMethod();
 
-  ClassDef(MCalibrationChargePix, 1)	// Container for Calibration of one pixel
+  ClassDef(MCalibrationChargePix, 1)	// Container for Charge Calibration Results Pixel
 };
 
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationPix.cc	(revision 3645)
@@ -25,6 +25,17 @@
 // MCalibrationPix                                                         //
 //                                                                         //
-// Base Storage container to for a calibration pixel                       //
-//                                                                         //
+// Base Storage container for a calibration pixel. Holds mean and sigmas,  
+// their errors, the fit probability and the number of pickup events for 
+// the high-gain and the low-gain derived values.    
+//                                                                         
+// Errors are stored internally as variances, but are returned and filled 
+// as square root of the variances. 
+//
+// Calls to GetMean(), GetMeanErr(), GetSigma(), GetSigmaErr(), GetProb() or 
+// GetNumPickup() test first the bit kHiGainSaturation before returning 
+// the high-gain or low-gain value, analogue for the corr. Setters.
+//
+// The three flags: kValid, kExcluded and kHiGainSaturation may be set.
+//
 /////////////////////////////////////////////////////////////////////////////
 #include "MCalibrationPix.h"
@@ -37,4 +48,11 @@
 //
 // Default Constructor: 
+//
+// Sets:
+// - fPixId to -1
+// - fFlags to 0
+// 
+// Calls:
+// - Clear()
 //
 MCalibrationPix::MCalibrationPix(const char *name, const char *title)
@@ -52,5 +70,7 @@
 // ------------------------------------------------------------------------
 //
-// Invalidate values
+// Sets:
+// - all variables to -1
+// - all flags to kFALSE
 //
 void MCalibrationPix::Clear(Option_t *o)
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationPix.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationPix.h	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationPix.h	(revision 3645)
@@ -6,5 +6,4 @@
 #endif
 
-class MBadPixelsPix;
 class MCalibrationPix : public MParContainer
 {
@@ -15,17 +14,17 @@
   UInt_t  fFlags;       // Flag for the set bits
  
-  Float_t fHiGainMean;        // The mean reduced charge after the fit
-  Float_t fHiGainMeanVar;     // The error of reduced mean charge after the fit
-  Float_t fHiGainSigma;       // The sigma of the mean charge after the fit
-  Float_t fHiGainSigmaVar;    // The error of the sigma of the mean charge after the fit
-  Float_t fHiGainProb;        // The probability of the fit function 
-  Float_t fHiGainNumPickup;   // The number of pickup events in the high-gain
+  Float_t fHiGainMean;      // Mean from fit to high gain values
+  Float_t fHiGainMeanVar;   // Error of mean from fit to high gain values
+  Float_t fHiGainSigma;     // Sigma from fit to high gain values
+  Float_t fHiGainSigmaVar;  // Error of sigma from fit to high gain values
+  Float_t fHiGainProb;      // Probability of fit to high gain values
+  Float_t fHiGainNumPickup; // Number of pickup events in high-gain
   
-  Float_t fLoGainMean;        // The mean reduced charge after the fit
-  Float_t fLoGainMeanVar;     // The error of reduced mean charge after the fit
-  Float_t fLoGainSigma;       // The sigma of the mean charge after the fit
-  Float_t fLoGainSigmaVar;    // The error of the sigma of the mean charge after the fit
-  Float_t fLoGainProb;        // The probability of the fit function 
-  Float_t fLoGainNumPickup;   // The number of pickup events in the low-gain
+  Float_t fLoGainMean;      // Mean from fit to high gain values
+  Float_t fLoGainMeanVar;   // Error of mean from fit to low gain values
+  Float_t fLoGainSigma;     // Sigma of from fit to low gain values
+  Float_t fLoGainSigmaVar;  // Error of sigma from fit to low gain values
+  Float_t fLoGainProb;      // Probability of fit to low gain values
+  Float_t fLoGainNumPickup; // Number of pickup events in low-gain
 
   enum  { kHiGainSaturation, kExcluded, kValid };
@@ -94,5 +93,5 @@
   Bool_t  IsValid   ()         const;
 
-  ClassDef(MCalibrationPix, 1)	// Container for Calibration of one pixel
+  ClassDef(MCalibrationPix, 1)	// Base class container for Calibration Results Pixel
 };
 

Index: trunk/MagicSoft/Mars/mcalib/MCalibrationChargeCam.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationChargeCam.h	(revision 3644)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationChargeCam.h	(revision 3645)
@@ -40,8 +40,10 @@
   Float_t fMeanFluxPhesOuterPixelVar;     //  The variance of the number of photo-electrons INNER PIXEL  
 
-  Float_t fMeanFluxPhotonsInnerPixel;        //  The mean number of photo-electrons in an INNER PIXEL
-  Float_t fMeanFluxPhotonsInnerPixelVar;     //  The variance of the number of photo-electrons INNER PIXEL  
-  Float_t fMeanFluxPhotonsOuterPixel;        //  The mean number of photo-electrons in an INNER PIXEL
-  Float_t fMeanFluxPhotonsOuterPixelVar;     //  The variance of the number of photo-electrons INNER PIXEL  
+  Float_t fMeanFluxPhotonsInnerPixel;     //  The mean number of photo-electrons in an INNER PIXEL
+  Float_t fMeanFluxPhotonsInnerPixelVar;  //  The variance of the number of photo-electrons INNER PIXEL  
+  Float_t fMeanFluxPhotonsOuterPixel;     //  The mean number of photo-electrons in an INNER PIXEL
+  Float_t fMeanFluxPhotonsOuterPixelVar;  //  The variance of the number of photo-electrons INNER PIXEL  
+  
+  Byte_t fFlags;                          // Byte to hold the flags
   
 public: